package com.ruoyi.worktecket.service;

import java.util.List;
import com.ruoyi.worktecket.domain.WorkTicketSignatureTemplate;
import com.ruoyi.worktecket.dto.WorkTicketSignatureTemplateDTO;

/**
 * 作业票签字模板Service接口
 *
 * @author ruoyi
 * @date 2023-08-04
 */
public interface IWorkTicketSignatureTemplateService
{
    /**
     * 查询作业票签字模板
     *
     * @param id 作业票签字模板主键
     * @return 作业票签字模板
     */
    public WorkTicketSignatureTemplateDTO selectWorkTicketSignatureTemplateById(String id);

    /**
     * 查询作业票签字模板列表
     *
     * @param workTicketSignatureTemplate 作业票签字模板
     * @return 作业票签字模板集合
     */
    public List<WorkTicketSignatureTemplate> selectList(WorkTicketSignatureTemplateDTO workTicketSignatureTemplate);
    /**
     * 查询作业票签字模板列表
     *
     * @param workTicketSignatureTemplate 作业票签字模板
     * @return 作业票签字模板集合
     */
    public List<WorkTicketSignatureTemplateDTO> selectWorkTicketSignatureTemplateList(WorkTicketSignatureTemplateDTO workTicketSignatureTemplate);

    /**
     * 新增作业票签字模板
     *
     * @param workTicketSignatureTemplate 作业票签字模板
     * @return 结果
     */
    public int insertWorkTicketSignatureTemplate(WorkTicketSignatureTemplateDTO workTicketSignatureTemplate);

    /**
     * 修改作业票签字模板
     *
     * @param workTicketSignatureTemplate 作业票签字模板
     * @return 结果
     */
    public int updateWorkTicketSignatureTemplate(WorkTicketSignatureTemplateDTO workTicketSignatureTemplate);

    /**
     * 批量删除作业票签字模板
     *
     * @param ids 需要删除的作业票签字模板主键集合
     * @return 结果
     */
    public int deleteWorkTicketSignatureTemplateByIds(Long[] ids);

}
